import React from 'react';
import { CallbackRef, Ref } from '../types';
export declare const isCallbackRef: <T>(callback: unknown) => callback is CallbackRef<T>;
export declare const isRef: <T>(ref: unknown) => ref is React.MutableRefObject<T>;
export declare const toFnRef: <T>(ref?: React.MutableRefObject<T> | CallbackRef<T> | null | undefined) => CallbackRef<T>;
export declare function mergeRefs<T>(...refs: Array<Ref<T> | null | undefined>): CallbackRef<T>;
/**
 * Create and returns a single callback ref composed from two other Refs.
 *
 * ```tsx
 * const Button = React.forwardRef((props, ref) => {
 *   const [element, attachRef] = useCallbackRef<HTMLButtonElement>();
 *   const mergedRef = useMergedRefs(ref, attachRef);
 *
 *   return <button ref={mergedRef} {...props}/>
 * })
 * ```
 *
 * @param refA A Callback or mutable Ref
 * @param refB A Callback or mutable Ref
 * @param refs another refs or mutable Ref
 * @category refs
 */
declare function useMergedRefs<T>(refA?: Ref<T> | null, refB?: Ref<T> | null, ...refs: Array<Ref<T> | null>): CallbackRef<T>;
export default useMergedRefs;
